@Echo OFF
REM ;******************************************************************************
REM ;**                                                                          **
REM ;**  Copyright 2014 Intel Corporation. All Rights Reserved.                  **
REM ;**                                                                          **
REM ;**  The material contained or described herein and all documents related    **
REM ;**  to such material ("Material") is owned by Intel Corporation or its      **
REM ;**  suppliers or licensors, and title to such Material remains with Intel   **
REM ;**  Corporation or its suppliers or licensors. The Material contains        **
REM ;**  proprietary information of Intel or its suppliers and licensors. The    **
REM ;**  Material is protected by worldwide copyright laws and treaty            **
REM ;**  provisions. No part of the Material may be used, copied, reproduced,    **
REM ;**  modified, published, uploaded, posted, transmitted, distributed or      **
REM ;**  disclosed in any way without Intel's prior express written permission.  **
REM ;**  No license under any patent, copyright or other intellectual property   **
REM ;**  rights in the Material is granted to or conferred upon you, either      **
REM ;**  expressly, by implication, inducement, estoppel or otherwise. Any       **
REM ;**  license under such intellectual property rights must be express and     **
REM ;**  approved by Intel in writing.                                           **
REM ;**                                                                          **
REM ;**  Unless otherwise agreed by Intel in writing, you may not remove or      **
REM ;**  alter this notice or any other notice embedded in Materials by Intel    **
REM ;**  or Intels suppliers or licensors in any way.                           **
REM ;******************************************************************************


REM ***************************************************************************************************
REM  WakeOnFastStartup.bat -  A batch file to set the WakeOnFastStartup registry value for 
REM  Intel(I217/I218 Network Connection.
REM
REM  This batch file uses the Windows Reg (Registry) command to search for an Intel(R) I217/I218/I219
REM  network adapter.  If one is found, the batch file will set the WakeOnFastStartup registry 
REM  to the desired value in the TargetValue variable.
REM
REM  In the "Set" commands below, the TargetValue variable should be set to the desired value.
REM
REM *****************************************************************************************************

@echo.
@echo.
@echo      ********** This batch file must be run with Administrator privileges.

REM ===========================================================================
REM  The WakeOnFastStartup value possibilites for the Intel Network Adapters
REM    "0" - WakeOnFastStartup disabled.
REM    "1" - WakeOnFastStartup enabled

REM Set our target WakeOnFastStartup to "1"  (enabled)

Set TargetValue="1"


REM =====================================================================================================
REM  - Definitions - these variables will be used to locate and set the desired value.

REM - Registry path to the Network Adapters Registry values.  The individual devices will be found at \0000, \0001, etc.
REM   under this path

set NetworkDevicePath=HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\Class\{4D36E972-E325-11CE-BFC1-08002BE10318}\

REM ======================================================
REM - The Friendly name of the device we are looking for.  This can match part or all of the string.  We will use
REM   "Intel(R) Ethernet Connection" as the search string because this string is in the I217/I218/I219 
REM   adapter brand names.   This can be more specifically targeted by updating the TargetDriverDesc variable to a 
REM   more complete adapter name.  This string must be in quotes for use by the FIND command.

set TargetDriverDesc="Intel(R) Ethernet Connection (2) I219-V"

REM ======================================================
REM The name of the value we are setting  (WakeOnFastStartup)

set TargetValueName=WakeOnFastStartup


REM ***************************************************************************************************
REM   Find our target device in the registry.
REM - Search for our target device in the registry.  This is straight-thru code.  No loops.  We use the 
REM   Windows Reg command to query the driver description of each of the first 16 network devices.  If 
REM   we find the correct description we continue to the next step.  If not, we bail out at the end.
REM
REM   The results of the REG QUERY command are piped to the FIND command.  The FIND command will set
REM   the ErrorLevel to 1 (or greater) if the target string is not found.

set DevNum=0000
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0001
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0002
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0003
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0004
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0005
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0006
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0007
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0008
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0009
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0010
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0011
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0012
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0013
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0014
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0015
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

set DevNum=0016
reg query %NetworkDevicePath%%DevNum% /v DriverDesc | find %TargetDriverDesc% >nul
if NOT ErrorLevel 1 goto FoundDevice

REM if it makes it here then no Intel(R) Network devices were found.  Print a message and exit

goto NoDevices

REM We found a device.  Print a message and proceed to setting the value.

:FoundDevice

@echo.
@echo.
@echo The %TargetDriverDesc% adapter was found at enum number %DevNum%
@echo.
@echo  Proceeding to set the %TargetValueName% registry setting to %TargetValue%.
@echo.
@echo.    "0" - WakeOnFastStartup Disabled.
@echo.    "1" - WakeOnFastStartup Enabled.
@echo.


Goto SetTargetValue

:NoDevices

@echo.
@echo.
@echo Could not find a %TargetDriverDesc% adapter to update.
@echo.
@echo  Possible causes:
@echo      No %TargetDriverDesc% adapters exist on this system.
@echo      The string %TargetDriverDesc% does not match the DriverDesc registry value.  (It is case-sensitive!)
@echo.
@echo  Exiting with no action

Goto done

:SetTargetValue

REM - Use the Reg ADD command to set the TargetValue (WakeOnFastStartup) to the desired value.

reg add %NetworkDevicePath%%DevNum% /v %TargetValueName% /t REG_SZ  /d %TargetValue% /f
reg add HKLM\SOFTWARE\1043 /v Version /t REG_SZ /d 1.0 /f

REM - Check for success or failure

if ErrorLevel 1 goto SetFail

@echo.
@echo.
@echo.
@echo Setting %TargetValueName% to %TargetValue%  SUCCESS.
@echo.
@echo.
@echo  The Network Driver must be re-started (disable/enable in Device Manager
@echo  or reboot the system) before the change will take effect.

Goto Done

:SetFail

@echo.
@echo.
@echo.
@echo Setting %TargetValueName% to %TargetValue%  FAILED.
@echo.
@echo.
@echo  Possible causes:
@echo      Permissions.  This batch file must be run with Administrator privileges.
@echo.



:Done


REM *********************************************************************************************
REM  This batch file is intended for the simplest case, a single Intel(R) Network adapter, and 
REM  to provide demonstration code for using the Windows REG command to locate an Intel(R) Network
REM  adapter and change a registry value.  If your system has multiple Intel(R) Network Adapters
REM  this batch file will only change the first instance found.
REm *********************************************************************************************
